@@ -15,15 +15,17 @@
 #include <qwidget.h>
 
 #include "amoranim.h"
-#include "amorwidget.h"
-#include "amorbubble.h"
 #include "amortips.h"
 #include "amorconfig.h"
-#include "amordialog.h"
 #include "AmorIface.h"
 
+class AmorDialog;
+class AmorBubble;
+class AmorWidget;
+
 class QTimer;
 class KWinModule;
+class KPopupMenu;
 
 //---------------------------------------------------------------------------
 //
@@ -45,6 +47,7 @@ public slots:
     void slotWindowRemove(WId);
     void slotStackingChanged();
     void slotWindowChange(WId);
+    void slotDesktopChange(int);
 
 protected slots:
     void slotMouseClicked(const QPoint &pos);
@@ -54,6 +57,7 @@ protected slots:
     void slotConfigChanged();
     void slotOffsetChanged(int);
     void slotAbout();
+    void slotWidgetDragged( const QPoint &delta, bool release );
     void restack();
     void hideBubble();
 
@@ -67,7 +71,6 @@ protected:
     AmorAnim *randomAnimation(QList<AmorAnim> &animList);
     void selectAnimation(State state=Normal);
     void active();
-    QRect windowGeometry(WId);
 
 private:
     KWinModule       *mWin;
@@ -85,7 +88,7 @@ private:
     QTimer           *mStackTimer; // Restacking timer
     QTimer           *mBubbleTimer;// Bubble tip timer
     AmorDialog       *mAmorDialog; // Setup dialog
-    QPopupMenu       *mMenu;       // Our menu
+    KPopupMenu       *mMenu;       // Our menu
     time_t           mActiveTime;  // The time an active event occurred
     QPoint           mCursPos;     // The last recorded position of the pointer
     QString          mTipText;     // Text to display in a bubble when possible
