@@ -16,6 +16,9 @@
 #include <qwidget.h>
 #include <qbitmap.h>
 
+class QTextBrowser;
+class QTimer;
+
 //---------------------------------------------------------------------------
 //
 // AmorBubble displays a message in a shaped window
@@ -38,6 +41,7 @@ protected:
     void drawBubble(QPainter &p);
     virtual void paintEvent(QPaintEvent *);
     virtual void mouseReleaseEvent(QMouseEvent *);
+    virtual bool eventFilter( QObject *, QEvent * );
 
 protected:
     QString mMessage;           // message to display
@@ -47,6 +51,8 @@ protected:
     QBitmap mMask;              // shape mask
     VertPos mArrowVert;         // vertical position of the arrow
     HorzPos mArrowHorz;         // horizontal position of the arrow
+    QTextBrowser *mBrowser;	// displays the message
+    QTimer *mBubbleTimer;	// hide timer
 };
 
 #endif // AMORBUBBLE_H
