@@ -117,8 +117,8 @@ void EyesApplet::drawPupils(QPainter* p)
 
     if(vect.x() * vect.x() + vect.y() * vect.y() > (width()/4 - tmp) * (width()/4 - tmp)*
        cos_alpha * cos_alpha+ (height()/2-tmp) * (height()/2-tmp) * sin_alpha * sin_alpha) {
-        pos.setX((width()/4-tmp) * cos_alpha+width()/4);
-        pos.setY((height()/2-tmp) * sin_alpha+height()/2);
+        pos.setX(int((width()/4-tmp) * cos_alpha+width()/4));
+        pos.setY(int((height()/2-tmp) * sin_alpha+height()/2));
     }
     else
 	pos = mouse;
@@ -150,8 +150,8 @@ void EyesApplet::drawPupils(QPainter* p)
     if(vect.x()*vect.x() + vect.y()*vect.y() > (width()/4-tmp)*(width()/4-tmp)
        *cos_alpha*cos_alpha+(height()/2-tmp)*(height()/2-tmp)*sin_alpha*sin_alpha)
     {
-        pos.setX((width()/4-tmp)*cos_alpha+3*width()/4);
-        pos.setY((height()/2-tmp)*sin_alpha+height()/2);
+        pos.setX(int((width()/4-tmp)*cos_alpha+3*width()/4));
+        pos.setY(int((height()/2-tmp)*sin_alpha+height()/2));
     }
     else
 	pos = mouse;
