@@ -23,36 +23,29 @@
 
 #include <X11/Xlib.h>
 
-typedef struct
-{
-    Window root;
-    Screen *scr;
-    int height, width;
-    double PixelsPerMM;
-} _screenInfo;
-
-
 class EyesApplet : public KPanelApplet
 {
-  Q_OBJECT
-	
-public:
-  EyesApplet(const QString& configFile, Type t = Normal, int actions = 0,
-             QWidget *parent = 0, const char *name = 0);
+    Q_OBJECT
 
-  int widthForHeight(int height);
-  int heightForWidth(int width);
+public:
+    EyesApplet(const QString& configFile, Type t = Normal, int actions = 0,
+               QWidget *parent = 0, const char *name = 0);
+
+    int widthForHeight(int height) const;
+    int heightForWidth(int width) const;
 
 protected:
-  void timerEvent(QTimerEvent*);
-  void resizeEvent(QResizeEvent*);
-  void paintEvent(QPaintEvent*);
+    void timerEvent(QTimerEvent*);
+    void resizeEvent(QResizeEvent*);
+    void paintEvent(QPaintEvent*);
 
-  QPoint oldPoint1,oldPoint2;
-  Display *display;
-  Window root, RootIDRet, ChildIDRet;
-  int sizeEye;
-  unsigned int StateMask;
+private:
+    void drawPupils(QPainter* p);
+
+    QPoint oldleft, oldright;
+    Display *display;
+    Window root, RootIDRet, ChildIDRet;
+    unsigned int StateMask;
 };
 
 #endif // __eyes_h__
