@@ -25,15 +25,18 @@
 #include <qimage.h>
 #include <sys/types.h>
 #include <time.h>
+#include <ksystemtray.h>
 
-class MoonWidget : public QWidget
+class MoonWidget : public QLabel
 {
     Q_OBJECT
 
 public:
     MoonWidget(QWidget *parent = 0, const char *name = 0);
     void calcStatus( time_t time );
-	void setAngle(int angle);
+    void setAngle(int angle);
+    bool northHemi() const { return north; }
+    void setNorthHemi(bool b);
 
 protected:
     QImage loadMoon(int index);
@@ -43,22 +46,24 @@ protected:
     int old_counter;
     int old_w, old_h, old_a;
     QString tooltip;
+    bool old_north, north;
 
 protected slots:
 
     void timerEvent( QTimerEvent *e);
     void showAbout();
-	void settings();
+    void settings();
 
 protected:
     void renderGraphic();
     virtual void paintEvent( QPaintEvent *e);
     virtual void resizeEvent( QResizeEvent *e);
     virtual void mousePressEvent( QMouseEvent *e);
+    virtual void enterEvent( QEvent *e);
 
 private:
-  int id_about;
-  int id_quit;
+    int id_about;
+    int id_quit;
 };
 
 #endif
