@@ -27,19 +27,23 @@ class QSlider;
 class MoonWidget;
 
 class KMoonDlg : public KDialogBase {
-	Q_OBJECT
-		
- public:
-	KMoonDlg(int angle, QWidget *parent, const char *name);
-	int getAngle() const { return angle; }
+    Q_OBJECT
 
- private:
-	QSlider *slider;
-	MoonWidget *moon;
-	int angle;
+public:
+    KMoonDlg(int angle, bool north, QWidget *parent, const char *name);
+    int getAngle() const { return angle; }
+    bool northHemi() const { return north; }
+
+private:
+    QSlider *slider;
+    MoonWidget *moon;
+    int angle;
+    bool north;
 
  private slots:
     void valueChanged(int);
+    void help();
+    void toggleHemi();
 
 };
 
