@@ -111,7 +111,7 @@ if ( Online && (!Downloading) )
 
 //          URL = "/tmp/mlb.html";
 //       cout << "Downloading " << URL.latin1() << "\n";
-       Scoreboard = "\0";
+       Scoreboard = QString::null;
 
        QString localFile = "/tmp/kscore_temp";
 
@@ -125,85 +125,75 @@ if ( Online && (!Downloading) )
 
 void  KscoreApplet::readOutput( KProcess *, char *buffer, int buflen)
 {
-int oldLength = Output.length();
-Output+=buffer;
-Output=Output.left(oldLength+buflen);
-//cout << "Parsing score\n";
+    Output += QString::fromLatin1( buffer, buflen );
 }
 
 void  KscoreApplet::finishOutput( KProcess *)
 {
-proc.kill();
+    proc.kill();
 
-//parse Output
-HomeName = "\0"; VisitorsName = "\0";
-HomeScore = "\0"; VisitorsScore = "\0";
-Period = "\0"; Date = "\0";
-Output.replace(QRegExp("_")," ");
-HomeName = Output.left(Output.find("\n"));
-Output = Output.remove(0,(Output.find("\n")+1));
-HomeScore = Output.left(Output.find("\n"));
-Output = Output.remove(0,(Output.find("\n")+1));
-VisitorsName = Output.left(Output.find("\n"));
-Output = Output.remove(0,(Output.find("\n")+1));
-VisitorsScore = Output.left(Output.find("\n"));
-Output = Output.remove(0,(Output.find("\n")+1));
-Period = Output.left(Output.find("\n"));
-Output = Output.remove(0,(Output.find("\n")+1));
-Date = Output.left(Output.find("\n"));
-update();
-Downloading = false;
-//cout << "Read score.\n";
+    //parse Output
+    Output.replace(QRegExp("_")," ");
+    HomeName = Output.left(Output.find("\n"));
+    Output = Output.remove(0,(Output.find("\n")+1));
+    HomeScore = Output.left(Output.find("\n"));
+    Output = Output.remove(0,(Output.find("\n")+1));
+    VisitorsName = Output.left(Output.find("\n"));
+    Output = Output.remove(0,(Output.find("\n")+1));
+    VisitorsScore = Output.left(Output.find("\n"));
+    Output = Output.remove(0,(Output.find("\n")+1));
+    Period = Output.left(Output.find("\n"));
+    Output = Output.remove(0,(Output.find("\n")+1));
+    Date = Output.left(Output.find("\n"));
+
+    update();
+    Downloading = false;
 }
 
-
 void  KscoreApplet::paintEvent( QPaintEvent * )
 {
-		QPainter p;
-		p.begin( this );
-		p.setPen( Text_color );
-		if ( orientation() == Horizontal )
-			{
-			if (VisitorsName == "NO SCORE")
-					{
-					p.setFont( QFont( "times", 9, QFont::Bold ) );
-					p.drawText( 26, 16, i18n("NO  SCORE"));
-					p.drawText( 23, 32, i18n("AVAILABLE"));
-					}
-            else
-					{
-					p.setFont( QFont( "times", 9, QFont::Bold ) );
+    QPainter p( this );
+    p.setPen( Text_color );
+    if ( orientation() == Horizontal )
+    {
+        if (VisitorsName == "NO SCORE")
+        {
+            p.setFont( QFont( "times", 9, QFont::Bold ) );
+            p.drawText( 26, 16, i18n("NO  SCORE"));
+            p.drawText( 23, 32, i18n("AVAILABLE"));
+         }
+       else
+       {
+            p.setFont( QFont( "times", 9, QFont::Bold ) );
 //					p.setFont( QFont( "times", 9 ) );
-					p.drawText( 3, 12, HomeName, 11);
-					p.drawText( 3, 24, VisitorsName, 11);
-					p.drawText( 73,  0, 12, 14, AlignBottom | AlignRight,  HomeScore);
-					p.drawText( 73, 12, 12, 14, AlignBottom | AlignRight, VisitorsScore);
+            p.drawText( 3, 12, HomeName.left( 11 ));
+            p.drawText( 3, 24, VisitorsName.left(  11 ));
+            p.drawText( 73,  0, 12, 14, AlignBottom | AlignRight,  HomeScore);
+            p.drawText( 73, 12, 12, 14, AlignBottom | AlignRight, VisitorsScore);
 //					p.drawText( 76, 12, HomeScore);
 //					p.drawText( 76, 24, VisitorsScore);
-					p.drawText( 3, 36, Period);
-					p.drawText( 48, 36, Date);
-					}
-			}
+            p.drawText( 3, 36, Period);
+            p.drawText( 48, 36, Date);
+        }
+    }
+    else {
+        if (VisitorsName == "NO SCORE") {
+            p.setFont( QFont( "times", 8, QFont::Bold ) );
+            p.drawText( 13, 20, i18n("NO") );
+            p.drawText( 6, 33, i18n("SCORE") );
+        }
         else
-			{
-			if (VisitorsName == "NO SCORE")
-					{
-					p.setFont( QFont( "times", 8, QFont::Bold ) );
-					p.drawText( 13, 20, i18n("NO") );
-					p.drawText( 6, 33, i18n("SCORE") );
-					}
-         else
-					{
+        {
 //					p.setFont( QFont( "times", 9 ) );
-					p.setFont( QFont( "times", 9, QFont::Bold ) );
-					p.drawText( 2, 12, HomeName, 4);
-					p.drawText( 2, 22, VisitorsName, 4);
-					p.drawText( 28,  2, 14, 12, AlignBottom | AlignRight, HomeScore);
-					p.drawText( 28, 12, 14, 12, AlignBottom | AlignRight, VisitorsScore);
-					p.drawText( 2, 35, Period);
-					p.drawText( 2, 45, Date.right( Date.length()-4 ) );
-					}
-			}
+            p.setFont( QFont( "times", 9, QFont::Bold ) );
+            p.drawText( 2, 12, HomeName.left( 4 ));
+            p.drawText( 2, 22, VisitorsName.left( 4 ));
+            p.drawText( 28,  2, 14, 12, AlignBottom | AlignRight, HomeScore);
+            p.drawText( 28, 12, 14, 12, AlignBottom | AlignRight, VisitorsScore);
+            p.drawText( 2, 35, Period);
+            p.drawText( 2, 45, Date.right( Date.length()-4 ) );
+        }
+    }
 }
 
 void KscoreApplet::mousePressEvent( QMouseEvent *event)
@@ -279,7 +269,8 @@ void KscoreApplet::loadFile( KIO::Job *aJob )
 	Scoreboard.insert(0, "\n"); Scoreboard.insert(0, Team );
     Scoreboard.insert(0, "\n"); Scoreboard.insert(0, League );
     //Parse scoreboard
-    Output = "\0";
+    Output = QString::null;
+
 	proc.clearArguments();
 	proc << "kscore_excite.pl";
 
@@ -292,8 +283,7 @@ void KscoreApplet::loadFile( KIO::Job *aJob )
 	else
 	{
 
-		QPainter p;
-		p.begin( this );
+		QPainter p( this );
 		p.setPen( Text_color );
 		p.eraseRect( this->rect() );
 		if ( orientation() == Horizontal )
