@@ -28,7 +28,7 @@ KWWApplet::KWWApplet(const QString& configFile, Type type, int actions,
   : KPanelApplet(configFile, type, actions, parent, name)
 {
   // make use of the icons installed for ksaferppp
-  KGlobal::iconLoader()->addAppDir("kworldwatch");
+  KGlobal::iconLoader()->addAppDir("kworldclock");
 
   QVBoxLayout *vbox = new QVBoxLayout(this, 0,0);
   
