@@ -56,13 +56,13 @@ MapWidget::MapWidget(bool applet, bool restore, QWidget *parent, const char *nam
 
   int id;
   _flagPopup = new QPopupMenu(this);
-  QPixmap flag = QPixmap(locate("data", "kworldwatch/pics/flag-red.png"));
+  QPixmap flag = QPixmap(locate("data", "kworldclock/pics/flag-red.png"));
   id = _flagPopup->insertItem(QIconSet(flag), i18n("Add &red"), this, SLOT(addFlag(int)));
   _flagPopup->setItemParameter(id, 0);
-  flag = QPixmap(locate("data", "kworldwatch/pics/flag-green.png"));
+  flag = QPixmap(locate("data", "kworldclock/pics/flag-green.png"));
   id = _flagPopup->insertItem(QIconSet(flag), i18n("Add &green"), this, SLOT(addFlag(int)));
   _flagPopup->setItemParameter(id, 1);
-  flag = QPixmap(locate("data", "kworldwatch/pics/flag-blue.png"));
+  flag = QPixmap(locate("data", "kworldclock/pics/flag-blue.png"));
   id = _flagPopup->insertItem(QIconSet(flag), i18n("Add &blue"), this, SLOT(addFlag(int)));
   _flagPopup->setItemParameter(id, 2);
   id = _flagPopup->insertItem(i18n("Add &custom..."), this, SLOT(addFlag(int)));
